@@ -4,6 +4,9 @@
 # Univention Management Console
 #  Base class for UMC 2.0 command handlers
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2006-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -34,8 +37,8 @@
 Python API for UMC modules
 ==========================
 
-The python API for UMC modules primary consists of one base class that
-must be implemented. As an addition the python API provides some helper
+The Python API for UMC modules primary consists of one base class that
+must be implemented. As an addition the Python API provides some helper
 functions and classes:
 
 * exception classes
@@ -47,7 +50,7 @@ The XML file defining the UMC module specifies functions for the
 commands provided by the module. These functions must be implemented as
 methods of a class named *Instance* that inherits :class:`.Base`.
 
-The following python code example matches the definition in the previous section::
+The following Python code example matches the definition in the previous section::
 
 	from univention.management.console import Translation
 	from univention.management.console.config import ucr
@@ -258,7 +261,7 @@ class Base(signals.Provider, Translation):
 
 		accepted_locales = re.split(r'\s*,\s*', request.headers.get('Accept-Language', ''))
 		if accepted_locales:
-			self.update_language(l.replace('-', '_') for l in accepted_locales)
+			self.update_language(loc.replace('-', '_') for loc in accepted_locales)
 
 	def security_checks(self, request, function):
 		if request.http_method not in (u'POST', u'PUT', u'DELETE') and not getattr(function, 'allow_get', False):
